==> mutt-0.58.tar.gz: mutt-0.58/acconfig.h <==

/* Does your version of PGP support the PGPPASSFD environment variable? */
#define HAVE_PGPPASSFD

/* Disable the X-Mailer header? */
#undef NO_XMAILER

/* Use fcntl() to lock folders? */
#define USE_FCNTL

/* Use flock() to lock folders?  (Don't use under Linux!) */
#undef USE_FLOCK
@TOP@

/* Do you want support for the POP3 protocol? (--enable-pop) */
#undef USE_POP

/*
 * Is mail spooled to the user's home directory?  If defined, MAILPATH should
 * be set to the filename of the spool mailbox relative the the home
 * directory.
 * use: configure --with-homespool=FILE
 */
#undef HOMESPOOL

/* Where new mail is spooled */
#undef MAILPATH

/* Should I just use the domain name? (--enable-hidden-host) */
#undef HIDDEN_HOST

/* Does your system have the srand48() suite? */
#undef HAVE_SRAND48

/* Where to find sendmail on your system */
#undef SENDMAIL

/* Where is PGP located on your system? */
#undef _PGPPATH

/* Where to find ispell on your system? */
#undef ISPELL

/* Should Mutt run setgid "mail" ? */
#undef USE_SETGID

#undef WORLD_WRITABLE_SPOOL

/* What is your domain name? */
#undef DOMAIN

/* Should the domain name be appended to unqualified addresses? */
#undef USE_DOMAIN

/* Create .lock files to lock folders? */
#undef USE_DOTLOCK

/* Does your curses library support color? */
#undef HAVE_COLOR

/* does your sendmail support DSN? (--enable-dsn) */
#undef USE_DSN

/* does your sendmail have the -B<encoding> option? (--enable-8bitmime) */
#undef USE_8BITMIME

/* Are we using GNU regex? */
#undef USE_GNU_REGEX

/* Suppress generation of the From: header field? */
#undef DONT_ADD_FROM

/* Compiling with SLang instead of curses/ncurses? */
#undef USE_SLANG_CURSES

==> mutt_0.88.orig.tar.gz: mutt-0.88/acconfig.h <==

/* Enable debugging info */
#define DEBUG

/* Does your version of PGP support the PGPPASSFD environment variable? */
#define HAVE_PGPPASSFD

/* Disable the X-Mailer header? */
#undef NO_XMAILER

/* What is your domain name? */
#undef DOMAIN
@TOP@

/* use dotlocking to lock mailboxes? */
#undef USE_DOTLOCK

/* use flock() to lock mailboxes? */
#undef USE_FLOCK

/* Use fcntl() to lock folders? */
#undef USE_FCNTL

/*
 * Define if you have problems with mutt not detecting new/old mailboxes
 * over NFS.  Some NFS implementations incorrectly cache the attributes
 * of small files.
 */
#undef NFS_ATTRIBUTE_HACK

/* Do you want support for the POP3 protocol? (--enable-pop) */
#undef USE_POP

/*
 * Is mail spooled to the user's home directory?  If defined, MAILPATH should
 * be set to the filename of the spool mailbox relative the the home
 * directory.
 * use: configure --with-homespool=FILE
 */
#undef HOMESPOOL

/* Where new mail is spooled */
#undef MAILPATH

/* Should I just use the domain name? (--enable-hidden-host) */
#undef HIDDEN_HOST

/* Does your system have the srand48() suite? */
#undef HAVE_SRAND48

/* Where to find sendmail on your system */
#undef SENDMAIL

/* Where is PGP located on your system? */
#undef _PGPPATH

/* Where to find ispell on your system? */
#undef ISPELL

/* Should Mutt run setgid "mail" ? */
#undef USE_SETGID

/* Does your curses library support color? */
#undef HAVE_COLOR

/* Are we using GNU rx? */
#undef USE_GNU_RX

/* Compiling with SLang instead of curses/ncurses? */
#undef USE_SLANG_CURSES

/* program to use for shell commands */
#define EXECSHELL "/bin/sh"

/* The "buffy_size" feature */
#undef BUFFY_SIZE

/* The result of isprint() is unreliable? */
#undef LOCALES_HACK
